package com.jiuqi.util;

import org.eclipse.osgi.util.ManifestElement;
import java.util.jar.Attributes;
import java.io.OutputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.util.jar.JarFile;
import java.io.InputStream;
import java.io.IOException;
import java.io.FileInputStream;
import java.io.File;
import java.util.jar.Manifest;

public class ManifestUtil
{
    public static final String MANIFEST_FILE_PATH = "/META-INF/MANIFEST.MF";
    
    public static Manifest getManifest(final String path) {
        return getManifest(new File(path));
    }
    
    public static Manifest getManifest(final File file) {
        if (file == null || !file.exists()) {
            return null;
        }
        if (file.isDirectory()) {
            return getManifestFromDir(file);
        }
        if (file.isFile()) {
            return getManifestFromJar(file);
        }
        return null;
    }
    
    public static Manifest getManifestFromDir(final String path) {
        Manifest manifest = null;
        try {
            final InputStream in = new FileInputStream(String.valueOf(path) + "/META-INF/MANIFEST.MF");
            manifest = new Manifest(in);
        }
        catch (final IOException ex) {
            manifest = null;
        }
        return manifest;
    }
    
    public static Manifest getManifestFromDir(final File file) {
        return getManifestFromDir(file.getAbsolutePath());
    }
    
    public static Manifest getManifestFromJar(final String path) {
        return getManifestFromJar(new File(path));
    }
    
    public static Manifest getManifestFromJar(final File file) {
        Manifest manifest = null;
        try {
            final JarFile jar = new JarFile(file);
            manifest = jar.getManifest();
        }
        catch (final IOException ex) {
            manifest = null;
        }
        return manifest;
    }
    
    public static void saveManifest(final String path, final Manifest manifest) {
        OutputStream out = null;
        try {
            out = new FileOutputStream(String.valueOf(path) + "/META-INF/MANIFEST.MF");
            manifest.write(out);
            out.close();
        }
        catch (final FileNotFoundException ex) {}
        catch (final IOException ex2) {}
    }
    
    public static String getAttributeRawValue(final Attributes attributes, final String attributeName) {
        return attributes.getValue(attributeName);
    }
    
    public static String getAttributeValue(final Attributes attributes, final String attributeName) {
        final String[] values = getAttributeValues(attributes, attributeName);
        return (values.length > 0) ? values[0] : null;
    }
    
    public static String[] getAttributeValues(final Attributes attributes, final String attributeName) {
        final String rawValue = getAttributeRawValue(attributes, attributeName);
        if (rawValue == null) {
            return new String[0];
        }
        String[] values = null;
        try {
            final ManifestElement[] elements = ManifestElement.parseHeader(attributeName, rawValue);
            values = new String[elements.length];
            for (int i = 0; i < elements.length; ++i) {
                values[i] = elements[i].getValue();
            }
        }
        catch (final Exception e) {
            e.printStackTrace();
        }
        if (values == null) {
            values = new String[0];
        }
        return values;
    }
}
